import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fotsporquiz/providers/quiz_provider.dart';
import 'package:fotsporquiz/utils/validator.dart';
import 'package:provider/provider.dart';

import '../entities/quiz.dart';
import '../services/quiz.service.dart';
import 'Log_screen.dart';
import 'PlayerName_screen.dart';

class HomeScreen extends StatefulWidget {
  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  final QuizService quizService = QuizService();
  final GameCodeService gameCodeService = GameCodeService();
  final Validator validator = Validator();

  @override
  void dispose() {
    super.dispose();
  }

  TextEditingController gameCodeEditor = TextEditingController();

  @override
  Widget build(BuildContext context) {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
    var gameProvider = Provider.of<GameProvider>(context);
    return Scaffold(
      appBar: AppBar(
        title: Text(
          "Fotspor Quiz",
          style: Theme.of(context).textTheme.headline4!.copyWith(
              color: Colors.white, fontWeight: FontWeight.bold, fontSize: 30),
        ),
        centerTitle: true,
        automaticallyImplyLeading: false,
        elevation: 8,
        flexibleSpace: Container(
          decoration: const BoxDecoration(
            gradient: LinearGradient(
              colors: [Color.fromRGBO(186, 220, 91, 1), Colors.blueGrey],
            ),
          ),
        ),
        actions: [
          IconButton(
            onPressed: (() => {
                  showDialog(
                    context: context,
                    builder: (context) => AlertDialog(
                      title: const Text("Personvern"),
                      content:
                          const Text("Personvern er ikke implementert enda."),
                      actions: [
                        TextButton(
                          onPressed: () {
                            Navigator.pop(context);
                          },
                          child: const Text("Avbryt"),
                        ),
                      ],
                    ),
                  ),
                }), // Personvern screen
            icon: const Icon(Icons.privacy_tip),
          ),
        ],
      ),
      body: Stack(
        children: [
          SafeArea(
            child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: 20.0),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Spacer(flex: 1),
                  const Padding(
                    padding: EdgeInsets.only(bottom: 10),
                    child: Center(
                      child: Text(
                        "Har du en delingskode?",
                        style: TextStyle(
                            fontSize: 20, fontWeight: FontWeight.bold),
                      ),
                    ),
                  ),
                  TextField(
                    controller: gameCodeEditor,
                    decoration: const InputDecoration(
                      hintText: "Spillkode...",
                    ),
                  ),
                  const Spacer(flex: 1),
                  InkWell(
                    onTap: () {
                      if (validator.validateGameCode(gameCodeEditor.text)) {
                        if (gameCodeService
                            .gameCodeExist(gameCodeEditor.text)) {
                          gameProvider.setQuiz(
                            quizService.fetchQuiz(gameCodeEditor.text),
                          );
                          gameProvider.setCode(gameCodeEditor
                              .text); // Valid code gets sent to the provider for use

                          Navigator.pushReplacement(
                            context,
                            MaterialPageRoute(
                              builder: (context) => PlayerNameScreen(),
                            ),
                          );
                        } else {
                          showDialog(
                            context: context,
                            builder: (context) => AlertDialog(
                              title: const Text("Ugyldig spillkode."),
                              content: const Text(
                                  "Koden kan bare bestå av tall eller bokstaver."),
                              actions: [
                                TextButton(
                                  onPressed: () {
                                    Navigator.pop(context);
                                  },
                                  child: const Text(
                                    "Lukk",
                                    style: TextStyle(color: Colors.black),
                                  ),
                                )
                              ],
                            ),
                          );
                        }
                      } else {
                        showDialog(
                          context: context,
                          builder: (context) => AlertDialog(
                            title: const Text("Ugyldig spillkode."),
                            content: const Text(
                                "Koden kan bare bestå av tall eller bokstaver."),
                            actions: [
                              TextButton(
                                onPressed: () {
                                  Navigator.pop(context);
                                },
                                child: const Text(
                                  "Lukk",
                                  style: TextStyle(color: Colors.black),
                                ),
                              )
                            ],
                          ),
                        );
                      }
                    },
                    child: Container(
                      width: double.infinity,
                      alignment: Alignment.center,
                      padding: const EdgeInsets.all(20.0 * 0.75), //15
                      decoration: const BoxDecoration(
                        gradient: LinearGradient(
                            colors: [
                              Color.fromRGBO(186, 220, 91, 1),
                              Colors.blueGrey
                            ], //Fotspor color
                            begin: Alignment.centerLeft,
                            end: Alignment.centerRight),
                        borderRadius: BorderRadius.all(
                          Radius.circular(12),
                        ),
                      ),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          const Icon(Icons.navigate_next, color: Colors.white),
                          Text(
                            "Neste",
                            style: Theme.of(context)
                                .textTheme
                                .button!
                                .copyWith(color: Colors.white),
                          ),
                        ],
                      ),
                    ),
                  ),
                  const Spacer(flex: 1),
                  InkWell(
                    onTap: () {
                      // Navigator.pushReplacement(
                      //   context,
                      //   MaterialPageRoute(
                      //     builder: (context) => LogScreen(),
                      //   ),
                      // );
                    },
                    child: Container(
                        width: double.infinity,
                        alignment: Alignment.center,
                        padding: const EdgeInsets.all(20.0 * 0.75), //15
                        decoration: const BoxDecoration(
                          gradient: LinearGradient(
                              colors: [
                                Color.fromRGBO(186, 220, 91, 1),
                                Colors.blueGrey,
                              ], //Fotspor color
                              begin: Alignment.centerLeft,
                              end: Alignment.centerRight),
                          borderRadius: BorderRadius.all(
                            Radius.circular(12),
                          ),
                        ),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            const Icon(
                              Icons.history,
                              color: Colors.white,
                            ),
                            Text(" Logg",
                                style: Theme.of(context)
                                    .textTheme
                                    .button!
                                    .copyWith(color: Colors.white)),
                          ],
                        )),
                  ),
                  const Spacer(flex: 1),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}
