import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fotsporquiz/entities/player.dart';
import 'package:fotsporquiz/screens/HomeScreen_screen.dart';
import 'package:fotsporquiz/screens/Map_screen.dart';
import 'package:fotsporquiz/services/result.service.dart';
import 'package:provider/provider.dart';
import '../providers/quiz_provider.dart';
import '../utils/validator.dart';

class PlayerNameScreen extends StatefulWidget {
  @override
  State<PlayerNameScreen> createState() => _PlayerNameScreenState();
}

class _PlayerNameScreenState extends State<PlayerNameScreen> {
  final Validator validator = Validator();
  TextEditingController playerNameEditor = TextEditingController();
  bool isNickNameValid = false;
  Player player = Player(-1, '', -1, '');

  @override
  void dispose() {
    super.dispose();
  }

  // Returns to the home screen
  returnToHomeScreen(GameProvider p) {
    p.reset();
    Navigator.pushReplacement(
        context, MaterialPageRoute(builder: (context) => HomeScreen()));
  }

  @override
  Widget build(BuildContext context) {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
    var gameProvider = Provider.of<GameProvider>(context);

    return Scaffold(
      appBar: AppBar(
        title: Text("Spillkode: " + gameProvider.code),
        centerTitle: true,
        elevation: 8,
        flexibleSpace: Container(
          decoration: const BoxDecoration(
            gradient: LinearGradient(
              colors: [Color.fromRGBO(186, 220, 91, 1), Colors.blueGrey],
            ),
          ),
        ),
        automaticallyImplyLeading: false,
      ),
      body: Stack(
        children: [
          SafeArea(
            child: Padding(
              padding:
                  const EdgeInsets.symmetric(horizontal: 20.0, vertical: 15),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Spacer(flex: 2),
                  Text(
                    "Skriv inn kallenavn",
                    style: Theme.of(context).textTheme.headline4!.copyWith(
                        color: Colors.black, fontWeight: FontWeight.bold),
                  ),
                  TextField(
                      controller: playerNameEditor,
                      decoration: const InputDecoration(
                        hintText: "Kallenavn...",
                      )),
                  const Spacer(flex: 2),
                  InkWell(
                    onTap: () {
                      if (validator.validateNickName(playerNameEditor.text)) {
                        gameProvider.setNickname(playerNameEditor.text);
                        player = Player(ResultService.generateId(),
                            playerNameEditor.text, 0, gameProvider.code);
                        gameProvider.setPlayer(
                            player); // creates a player if the nickname is valid
                        ResultService.addPlayer(
                            player); // player added to the database/mockDatabase
                        Navigator.pushReplacement(
                          context,
                          MaterialPageRoute(
                            builder: (context) => const MapScreen(),
                          ),
                        );
                      } else {
                        showDialog(
                          context: context,
                          builder: (context) => AlertDialog(
                            title: const Text("Ugyldig kallenavn."),
                            content: const Text(
                                "Kallenavnet kan bare inneholde bokstaver, og noen få spesielle karakterer som -."),
                            actions: [
                              TextButton(
                                onPressed: () {
                                  Navigator.pop(context);
                                },
                                child: const Text(
                                  "Lukk",
                                  style: TextStyle(color: Colors.black),
                                ),
                              ),
                            ],
                          ),
                        );
                      }
                    },
                    child: Container(
                        width: double.infinity,
                        alignment: Alignment.center,
                        padding: const EdgeInsets.all(20.0 * 0.75), //15
                        decoration: const BoxDecoration(
                          gradient: LinearGradient(
                              colors: [
                                Color.fromRGBO(186, 220, 91, 1),
                                Colors.blueGrey,
                              ], //Fotspor color
                              begin: Alignment.centerLeft,
                              end: Alignment.centerRight),
                          borderRadius: BorderRadius.all(
                            Radius.circular(12),
                          ),
                        ),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            const Icon(
                              Icons.navigate_next,
                              color: Colors.white,
                            ),
                            Text(
                              "Start",
                              style: Theme.of(context)
                                  .textTheme
                                  .button!
                                  .copyWith(color: Colors.white),
                            ),
                          ],
                        )),
                  ),
                  const Spacer(flex: 2),
                  InkWell(
                    onTap: () {
                      returnToHomeScreen(gameProvider);
                    },
                    child: Container(
                      width: 150,
                      alignment: Alignment.center,
                      padding: const EdgeInsets.all(20.0 * 0.75), //15
                      decoration: const BoxDecoration(
                        gradient: LinearGradient(
                            colors: [
                              Color.fromRGBO(186, 220, 91, 1),
                              Colors.blueGrey,
                            ], //Fotspor color
                            begin: Alignment.centerLeft,
                            end: Alignment.centerRight),
                        borderRadius: BorderRadius.all(
                          Radius.circular(12),
                        ),
                      ),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          const Icon(
                            Icons.keyboard_return,
                            color: Colors.white,
                          ),
                          Text(
                            " Tilbake",
                            style: Theme.of(context)
                                .textTheme
                                .button!
                                .copyWith(color: Colors.white),
                          ),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}
