import 'dart:io';

import 'package:back_button_interceptor/back_button_interceptor.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fotsporquiz/entities/question.dart';
import 'package:fotsporquiz/providers/quiz_provider.dart';
import 'package:fotsporquiz/screens/Map_screen.dart';
import 'package:fotsporquiz/widgets/result.dart';
import 'package:provider/provider.dart';
import '../entities/post.dart';
import '../widgets/answerOption.dart';

class QuestionScreen extends StatefulWidget {
  final Post _post;

  QuestionScreen(this._post);

  @override
  State<QuestionScreen> createState() => _QuestionScreenState();
}

class _QuestionScreenState extends State<QuestionScreen> {
  int _questionIndex = 0;
  int questionNumber = 1;
  List<Question> _questions = [];
  final List<AnswerOption> _answers = [];

  @override
  void initState() {
    super.initState();
    _questions = widget._post.questions;
    BackButtonInterceptor.add(myInterceptor);
  }

  @override
  void dispose() {
    super.dispose();
    BackButtonInterceptor.remove(myInterceptor);
  }

  // Refuses back button to activate the back button in the MapScreen
  bool myInterceptor(bool stopDefaultButtonEvent, RouteInfo info) {
    return true;
  }

// Returns to the map screen
  returnToMap() {
    Navigator.pushReplacement(
        context, MaterialPageRoute(builder: (context) => const MapScreen()));
  }

// Changes the screen to the next question
  nextQuestion() {
    setState(() {
      _questionIndex++;
      if (_questionIndex < _questions.length) {
        questionNumber++;
      }
    });
  }

  // Generates a list of answerOptions, that gets displayed on the screen
  generateOptions(GameProvider p) {
    if (_questionIndex < _questions.length) {
      for (var answer in _questions[_questionIndex].answerOptions) {
        _answers.add(
          AnswerOption(
            answer.answer,
            answer.rightAnswer,
            (/*Function as parameter for what action an answerOption does when pressed*/
                () {
              if (answer.rightAnswer) {
                p.setScore(p.player.score + 1);
              }
              if (_questions[_questionIndex].explanation != "") {
                showDialog(
                  barrierDismissible: false,
                  context: context,
                  builder: (context) => AlertDialog(
                    title: const Text("Forklaring:"),
                    content: Text(_questions[_questionIndex].explanation),
                    actions: [
                      TextButton(
                        onPressed: () {
                          Navigator.pop(context);
                          nextQuestion();
                        },
                        child: const Text("Neste"),
                      ),
                    ],
                  ),
                );
              } else {
                nextQuestion();
              }
            }),
          ),
        );
      }
    }
  }

  resizeImage(String image) {
    Image newImage = Image.asset(
      image,
      height: 300,
      width: 300,
    );

    return newImage;
  }

  bool shouldPop = true;

  @override
  Widget build(BuildContext context) {
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);

    var gameProvider = Provider.of<GameProvider>(context);

    _answers.clear();

    generateOptions(gameProvider);

    return WillPopScope(
        onWillPop: () async {
          return shouldPop;
        },
        child: Scaffold(
          appBar: AppBar(
            title: Text(
              'Spørsmål: ' +
                  (questionNumber).toString() +
                  "/" +
                  _questions.length.toString(),
            ),
            //backgroundColor: const Color(0xFFBBDC5B),
            flexibleSpace: Container(
              decoration: const BoxDecoration(
                gradient: LinearGradient(
                  colors: [Color.fromRGBO(186, 220, 91, 1), Colors.blueGrey],
                ),
              ),
            ),
            centerTitle: true,
            elevation: 8,
            automaticallyImplyLeading: false,
          ),
          body: _questionIndex < _questions.length
              ? Column(
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(25),
                      child: Text(
                        _questions[_questionIndex].question,
                        style: const TextStyle(fontSize: 20),
                      ),
                    ),
                    const Spacer(flex: 2),

                    if (_questions[_questionIndex].image != "")
                      resizeImage(_questions[_questionIndex].image),

                    //Image.asset(_questions[_questionIndex].image),
                    const Spacer(flex: 4),
                    ..._answers,
                    const Spacer(flex: 2),
                  ],
                )
              : Result(gameProvider, (() {
                  gameProvider.setPostOpened(widget._post);
                }), returnToMap),
        ));
  }
}
